|pypi| |actions| |codecov| |downloads|


META Edc
--------

Metformin treatment in Africa- META

* https://www.ucl.ac.uk/global-health/research/z-research/respond-africa/metformin-treatment-africa-meta
* https://www.inteafrica.org/related-projects/meta-trial/
* https://www.lstmed.ac.uk/research/departments/international-public-health/respond-africa/meta
* http://www.isrctn.com/ISRCTN76157257

py 3.12 / DJ 5.1.5 / edc 1.0.3 (META3)

This codebase is used for two randomized clinical trials:

____

META PHASE II:

(final version `0.1.77 <https://github.com/meta-trial/meta-edc/tree/0.1.77>`_)

Metformin Treatment for Diabetes Prevention in Africa: META Trial
TASO, MRC/UVRI/LSHTM, NIMR – TZ and Liverpool School of Tropical Medicine (ISRCTN76157257)
http://www.isrctn.com/ISRCTN76157257

____

META PHASE III:

A randomised placebo-controlled double-blind phase III trial to determine the effects of metformin versus placebo on the incidence of diabetes in HIV-infected persons with pre-diabetes in Tanzania.

Liverpool School of Tropical Medicine

EDCTP grant number: RIA2018CO-2513

Trial registration: ISCRTN 77382043

https://ico.org.uk/ESDWebPages/Entry/Z4763134

____

See also https://github.com/clinicedc/edc

|django|

To setup a demo system, see https://github.com/meta-trial/meta3-sample


.. |pypi| image:: https://img.shields.io/pypi/v/meta-edc.svg
    :target: https://pypi.python.org/pypi/meta-edc

.. |actions| image:: https://github.com/meta-trial/meta-edc/actions/workflows/build.yml/badge.svg
  :target: https://github.com/meta-trial/meta-edc/actions/workflows/build.yml

.. |codecov| image:: https://codecov.io/gh/meta-trial/meta-edc/branch/develop/graph/badge.svg
  :target: https://codecov.io/gh/meta-trial/meta-edc

.. |downloads| image:: https://pepy.tech/badge/meta-edc
   :target: https://pepy.tech/project/meta-edc

.. |django| image:: https://www.djangoproject.com/m/img/badges/djangomade124x25.gif
   :target: http://www.djangoproject.com/
   :alt: Made with Django
